pub(crate) struct OngoingHistoryTraversalRequest {
pub traversal_request: SessionHistoryTraversalRequest,
pub pipelines_awaiting_activation: FxHashSet<PipelineId>,
}Expand description
A [HistoryTraversalRequest] that is in progress because it is waiting
for documents that need reloading.
Fields
traversal_request: SessionHistoryTraversalRequestThe [HistoryTraversalRequest] that spawned this series of navigations.
pipelines_awaiting_activation: FxHashSet<PipelineId>The ids of all the Pipelines that needed reloading for this traversal.
Multiple pipelines can be traversed if the top-level document contained
<iframe>s / browsing contexts. The traversal is only done when all of
the pipelines are ready or have failed to load.